
#line 3 "src/lexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 168
#define YY_END_OF_BUFFER 169
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[646] =
    {   0,
      164,  164,  169,  167,  164,  164,   49,    7,   11,  167,
       37,   48,  167,  163,    5,    3,   35,    1,    1,    4,
        6,  167,   43,   46,  165,  165,  165,  165,  165,  165,
      165,  165,  165,  165,  165,  165,  165,  165,  165,  165,
      165,  165,   38,  165,   36,   45,    2,  167,   44,   34,
       12,   13,   14,   39,   64,   65,    8,   40,  167,  167,
      167,    0,  164,    0,   70,    0,    0,    1,    1,   47,
       74,    0,    0,    0,    0,   73,    0,    0,    0,    0,
        0,   51,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   15,   16,   17,    0,    0,    0,
        0,    0,   70,    0,   50,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   52,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   62,    0,   63,   61,    0,  121,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   71,    0,    0,    0,    0,    0,   31,
       32,   33,   18,   19,   20,   21,   22,   23,   24,   25,
       26,   27,   28,   29,   30,   42,  166,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  139,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  136,   66,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   41,    0,
        0,    9,   10,    0,    0,    0,   68,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   57,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,    0,   86,    0,
        0,  145,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  158,
        0,  135,    0,    0,    0,   85,   78,  142,    0,  149,
        0,    0,    0,    0,   94,    0,    0,   89,   69,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       54,   53,    0,    0,    0,    0,    0,    0,  150,    0,
        0,   82,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,  102,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,  120,    0,  159,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,    0,  153,    0,    0,
      154,    0,    0,    0,    0,    0,  147,   58,    0,    0,
        0,    0,  138,  122,    0,    0,    0,    0,    0,   67,
        0,  110,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,  146,  114,    0,    0,    0,    0,
        0,    0,    0,   77,    0,    0,  132,    0,    0,    0,
      118,    0,    0,    0,    0,    0,    0,    0,  160,  161,
        0,    0,    0,    0,   87,    0,    0,    0,   96,   91,
      111,  109,    0,    0,    0,  126,    0,    0,    0,   55,
        0,    0,    0,   81,  152,    0,    0,   98,   84,   90,

        0,    0,    0,   88,  144,    0,    0,    0,    0,    0,
      101,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      117,    0,  140,    0,    0,    0,    0,    0,  156,    0,
        0,  125,  141,    0,    0,    0,  151,    0,   97,    0,
        0,    0,    0,    0,    0,    0,    0,  105,    0,  106,
        0,    0,    0,    0,    0,    0,    0,  116,  104,    0,
      133,  131,   79,    0,    0,    0,    0,  134,  119,    0,
      157,    0,    0,  127,    0,    0,    0,    0,   80,  155,
        0,    0,    0,    0,    0,    0,    0,    0,  112,    0,
        0,    0,    0,   92,  115,  113,    0,  103,    0,    0,

       75,   76,    0,  130,  162,  143,    0,    0,    0,   93,
       59,    0,    0,    0,  124,  128,    0,  137,    0,    0,
      108,  100,  148,    0,    0,    0,  123,    0,    0,    0,
        0,    0,   56,   83,    0,    0,  129,   95,   60,   99,
        0,  107,    0,   72,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    4,    5,    6,    7,    8,    9,   10,
       11,    1,   12,   13,   14,   15,   16,   17,   17,   18,
       18,   18,   18,   17,   17,   17,   17,   19,   20,   21,
        1,    1,   22,   23,   24,   25,   26,   27,   28,   29,
       30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
       40,   41,   42,   43,   44,   45,   46,   47,   48,   33,
        1,   49,    1,   50,   51,    1,    1,    1,   52,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,   53,    1,   54,    1,   55,    1,   56,
        1,    1,    1,    1,    1,   57,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,   58,
       59,   60,   61,   62,   63,   64,   65,   66,   67,   68,
       69,   70,    1,    1,    1,    1,    1,   71,   72,    1,
        1,    1,    1,   73,    1,    1,    1,    1,   74,   75,
       76,    1,    1,   77,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,   78,    1,   79,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[80] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1
    } ;

static const flex_int16_t yy_base[647] =
    {   0,
        0,    0,  967,  916,   78,   80,  915,  914,  913,   82,
      912,  911,   84,  910,  909,  908,  907,   86,   88,  906,
      905,   79,  904,  903,   83,   44,   71,   87,   67,  102,
      103,  902,  112,  118,  123,  122,   70,  113,   72,  111,
      131,  128,  901,  135,  900,  899,  898,  897,  896,  895,
      894,  893,  892,  891,  890,  889,  888,  887,  127,  121,
      108,  905,   94,  180,  188,  190,  193,  197,  199,  968,
      968,  893,  889,  909,  900,  968,  896,   87,  902,  138,
      887,  968,  884,  901,  885,  887,  879,  210,  899,  885,
      877,  892,  889,  880,  869,  880,  880,  871,  866,  166,

      886,  874,  195,  872,  871,  194,  867,  883,  881,  857,
      873,  871,  870,  870,  968,  968,  968,  153,  824,  185,
      844,    0,  254,  256,  968,  855,  869,  864,  867,  868,
      232,  202,  869,  855,  852,  848,  861,  968,  858,  851,
      858,  259,  854,  860,  846,  840,  843,  852,  838,  850,
      838,  851,  843,  831,  968,  830,  968,  968,  844,  834,
      844,  845,  821,  830,  839,  827,  201,  827,  835,  818,
      820,  828,  817,  968,  263,  844,  822,  813,  216,  968,
      968,  968,  968,  968,  968,  968,  968,  968,  968,  968,
      968,  968,  968,  968,  968,  968,  968,  246,  818,  817,

      816,  808,  273,  814,  822,  821,  816,  806,  803,  818,
      816,  811,  240,  814,  968,  236,  813,  814,  809,  796,
      796,  245,  792,  248,  803,  806,  796,  800,  288,  968,
      799,  802,  787,  796,  800,  290,  791,  788,  783,  781,
      786,  785,  788,  794,  787,  294,  787,  779,  968,  266,
      271,  968,  968,  783,  777,  272,  968,  785,  777,  303,
      770,  780,  271,  782,  782,  307,  283,  779,  765,  769,
      777,  775,  759,  310,  762,  776,  765,  321,  760,  293,
      770,  768,  759,  767,  765,  755,  324,  759,  751,  327,
      748,  751,  750,  743,  757,  748,  759,  331,  745,  737,

      752,  752,  750,  734,  751,  303,  747,  746,  741,  748,
      741,  968,  733,  334,  732,  731,  739,  729,  724,  301,
      740,  725,  338,  734,  718,  732,  731,  341,  715,  345,
      312,  316,  733,  712,  711,  968,  711,  968,  726,  968,
      356,  721,  727,  709,  968,  712,  704,  968,  968,  703,
      358,  716,  362,  707,  709,  701,  707,  703,  710,  709,
      368,  372,  714,  701,  706,  692,  693,  689,  968,  708,
      703,  968,  693,  684,  331,  691,  695,  374,  696,  376,
      688,  694,  691,  346,  695,  693,  693,  691,  345,  682,
      382,  676,  675,  320,  674,  390,  686,  392,  388,  683,

      675,  684,  682,  668,  673,  671,  674,  968,  677,  678,
      968,  673,  666,  665,  401,  653,  968,  968,  671,  656,
      665,  660,  407,  968,  410,  671,  413,  656,  656,  968,
      415,  968,  664,  655,  273,  649,  659,  391,  661,  659,
      656,  648,  418,  654,  968,  968,  422,  646,  655,  653,
      636,  428,  635,  968,  651,  645,  431,  638,  637,  637,
      968,  645,  435,  441,  645,  630,  444,  446,  968,  968,
      626,  448,  641,  644,  968,  630,  642,  631,  968,  968,
      968,  968,  640,  635,  636,  463,  465,  620,  634,  968,
      632,  467,  614,  620,  968,  628,  428,  623,  968,  968,

      617,  609,  472,  968,  968,  628,  474,  614,  620,  605,
      968,  612,  476,  619,  610,  601,  607,  478,  480,  607,
      968,  612,  968,  482,  484,  597,  596,  505,  968,  603,
      487,  507,  968,  385,  608,  610,  968,  594,  598,  610,
      510,  512,  594,  603,  586,  586,  600,  968,  589,  968,
      586,  585,  591,  580,  489,  557,  558,  968,  968,  548,
      968,  516,  968,  542,  535,  522,  525,  968,  968,  530,
      968,  528,  525,  968,  535,  532,  519,  516,  968,  968,
      503,  469,  450,  549,  551,  435,  394,  396,  968,  384,
      387,  377,  366,  968,  968,  968,  282,  968,  553,  555,

      968,  968,  568,  968,  968,  968,  557,  578,  257,  968,
      574,  244,  235,  580,  968,  968,  235,  968,  205,  183,
      968,  968,  968,  585,  597,  602,  968,  148,  590,  141,
      123,   88,  968,  968,   91,  607,  968,  968,  968,  968,
      604,  968,  609,  968,  968,   97
    } ;

static const flex_int16_t yy_def[647] =
    {   0,
      645,    1,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,

      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  646,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  646,  645,  645,  646,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,

      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,

      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,

      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,

      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,

      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,    0,  645
    } ;

static const flex_int16_t yy_nxt[1048] =
    {   0,
        4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
        4,   14,   15,    4,   16,   17,   18,   19,   20,   21,
       22,   23,   24,   25,   26,   27,   28,   29,   30,   31,
       32,   33,   32,   32,   34,   35,   36,   37,   38,   39,
       40,   41,   42,   32,   43,   44,   32,   32,   45,   46,
       47,   48,   49,   50,    4,    4,    4,    4,    4,   51,
       52,   53,   54,    4,    4,    4,    4,   55,    4,   56,
        4,    4,    4,   57,   58,    4,   59,   60,   61,   63,
       63,   63,   63,   64,   64,   66,   66,   68,   68,   69,
       69,   76,   71,   62,   77,   63,   63,  197,   65,   65,

       67,   67,   68,   68,   68,   68,  101,   72,   78,   73,
       70,   79,   74,   83,   80,  105,   62,   75,   81,   62,
       62,   62,  131,  132,   82,   84,  642,   62,   62,  641,
       98,   62,   62,   62,   87,   62,   62,   62,  106,   85,
       88,   90,   86,   89,  102,   93,   95,  103,   91,   99,
       96,   62,   62,  104,   92,   94,  107,   62,  640,  100,
       62,   62,   62,  120,  121,  112,   97,   62,  110,  134,
       62,   62,   62,  108,  109,  113,   62,   62,  639,  135,
       62,   64,   64,  638,   62,  118,  115,  116,  117,  123,
      123,   66,   66,  119,  124,  124,   65,   65,   68,   68,

       69,   69,  157,  125,  123,  123,   67,   67,  158,  124,
      124,  142,  142,   68,   68,   68,   68,  165,  161,  166,
      167,   70,  162,  180,  181,  168,  635,  206,  238,  169,
      207,  252,  239,  143,  144,  170,  171,  274,  274,  208,
      634,  145,  183,  184,  185,  186,  187,  188,  189,  190,
      191,  192,  193,  194,  195,  123,  123,  124,  124,  203,
      142,  142,  633,  204,  246,  246,  125,  205,  253,  254,
      123,  123,  124,  124,  260,  260,  271,  255,  632,  275,
      272,  281,  143,  144,  284,  282,  247,  631,  285,  290,
      290,  298,  298,  312,  248,  246,  246,  313,  314,  318,

      628,  261,  315,  319,  260,  260,  324,  325,  328,  328,
      330,  274,  274,  496,  331,  497,  291,  247,  623,  292,
      345,  299,  341,  341,  346,  353,  353,  300,  290,  290,
      372,  261,  298,  298,  373,  380,  380,  387,  329,  391,
      391,  388,  328,  328,  342,  343,  398,  398,  400,  401,
      354,  460,  402,  275,  399,  291,  403,  341,  341,  415,
      415,  461,  355,  353,  353,  381,  392,  439,  300,  425,
      425,  440,  329,  427,  427,  443,  443,  380,  380,  342,
      343,  455,  449,  391,  391,  416,  450,  456,  354,  467,
      467,  463,  463,  398,  398,  622,  426,  444,  428,  464,

      355,  399,  415,  415,  468,  468,  621,  381,  487,  487,
      392,  425,  425,  620,  427,  427,  492,  492,  500,  443,
      443,  577,  501,  507,  507,  578,  465,  619,  416,  513,
      513,  618,  518,  518,  617,  488,  463,  463,  426,  428,
      519,  444,  524,  524,  464,  467,  467,  528,  528,  531,
      531,  549,  493,  508,  514,  550,  529,  525,  525,  551,
      468,  468,  528,  528,  541,  541,  487,  487,  492,  492,
      616,  532,  542,  555,  555,  507,  507,  513,  513,  518,
      518,  566,  566,  524,  524,  570,  570,  519,  531,  531,
      555,  555,  613,  488,  571,  612,  567,  567,  525,  525,

      570,  570,  514,  556,  493,  508,  528,  528,  575,  575,
      532,  541,  541,  584,  584,  529,  576,  599,  599,  542,
      556,  528,  528,  566,  566,  600,  603,  603,  585,  585,
      611,  570,  570,  607,  607,  604,  575,  575,  567,  567,
      571,  603,  603,  610,  576,  609,  570,  570,  608,  608,
      584,  584,  614,  614,  599,  599,  624,  624,  607,  607,
      606,  615,  600,  605,  602,  585,  585,  614,  614,  603,
      603,  625,  625,  608,  608,  629,  629,  601,  604,  626,
      626,  614,  614,  598,  603,  603,  624,  624,  627,  597,
      615,  629,  629,  596,  626,  626,  614,  614,  636,  636,

      630,  625,  625,  626,  626,  643,  643,  637,  636,  636,
      643,  643,  627,  636,  636,  595,  630,  637,  626,  626,
      594,  593,  592,  636,  636,  591,  590,  644,  589,  588,
      587,  586,  644,  583,  582,  581,  580,  579,  574,  573,
      572,  569,  568,  565,  564,  563,  562,  561,  560,  559,
      558,  557,  554,  553,  552,  548,  547,  546,  545,  544,
      543,  540,  539,  538,  537,  536,  535,  534,  533,  530,
      527,  526,  523,  522,  521,  520,  517,  516,  515,  512,
      511,  510,  509,  506,  505,  504,  503,  502,  499,  498,
      495,  494,  491,  490,  489,  486,  485,  484,  483,  482,

      481,  480,  479,  478,  477,  476,  475,  474,  473,  472,
      471,  470,  469,  466,  462,  459,  458,  457,  454,  453,
      452,  451,  448,  447,  446,  445,  442,  441,  438,  437,
      436,  435,  434,  433,  432,  431,  430,  429,  424,  423,
      422,  421,  420,  419,  418,  417,  414,  413,  412,  411,
      410,  409,  408,  407,  406,  405,  404,  397,  396,  395,
      394,  393,  390,  389,  386,  385,  384,  383,  382,  379,
      378,  377,  376,  375,  374,  371,  370,  369,  368,  367,
      366,  365,  364,  363,  362,  361,  360,  359,  358,  357,
      356,  352,  351,  350,  349,  348,  347,  344,  340,  339,

      338,  337,  336,  335,  334,  333,  332,  327,  326,  323,
      322,  321,  320,  317,  316,  311,  310,  309,  308,  307,
      306,  305,  304,  303,  302,  301,  297,  296,  295,  294,
      293,  289,  288,  287,  286,  283,  280,  279,  278,  277,
      276,  273,  270,  269,  268,  267,  266,  265,  264,  263,
      262,  259,  258,  257,  256,  251,  250,  249,  245,  244,
      243,  242,  241,  240,  237,  236,  235,  234,  233,  232,
      231,  230,  229,  228,  227,  226,  225,  224,  223,  222,
      221,  220,  219,  218,  217,  216,  215,  214,  213,  212,
      211,  210,  209,  202,  201,  200,  199,  198,  196,  182,

      179,  178,  177,  176,  175,  174,  173,  172,  164,  163,
      160,  159,  156,  155,  154,  153,  152,  151,  150,  149,
      148,  147,  146,  141,  140,  139,  138,  137,  136,  133,
      130,  129,  128,  127,  126,  122,   62,   62,   62,   62,
       62,   62,   62,   62,   62,   62,  114,   62,   62,   62,
      111,   62,   62,   62,   62,   62,   62,   62,   62,   62,
       62,   62,   62,   62,   62,   62,  645,    3,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,

      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645
    } ;

static const flex_int16_t yy_chk[1048] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    5,
        5,    6,    6,   10,   10,   13,   13,   18,   18,   19,
       19,   26,   22,   26,   27,   63,   63,  646,   10,   10,

       13,   13,   18,   18,   19,   19,   37,   25,   27,   25,
       19,   27,   25,   29,   28,   39,   29,   25,   28,   37,
       27,   39,   78,   78,   28,   30,  635,    5,   22,  632,
       36,   10,   25,   13,   31,   18,   28,   19,   40,   30,
       31,   33,   30,   31,   38,   34,   35,   38,   33,   36,
       35,   30,   31,   38,   33,   34,   41,   61,  631,   36,
       40,   33,   38,   61,   61,   44,   35,   34,   42,   80,
       60,   36,   35,   41,   41,   44,   59,   42,  630,   80,
       41,   64,   64,  628,   44,   60,   59,   59,   59,   65,
       65,   66,   66,   60,   67,   67,   64,   64,   68,   68,

       69,   69,  100,   67,   65,   65,   66,   66,  100,   67,
       67,   88,   88,   68,   68,   69,   69,  106,  103,  106,
      106,   69,  103,  118,  118,  106,  620,  132,  167,  106,
      132,  179,  167,   88,   88,  106,  106,  216,  216,  132,
      619,   88,  120,  120,  120,  120,  120,  120,  120,  120,
      120,  120,  120,  120,  120,  123,  123,  124,  124,  131,
      142,  142,  617,  131,  175,  175,  124,  131,  179,  198,
      123,  123,  124,  124,  203,  203,  213,  198,  613,  216,
      213,  222,  142,  142,  224,  222,  175,  612,  224,  229,
      229,  236,  236,  250,  175,  246,  246,  250,  251,  256,

      609,  203,  251,  256,  260,  260,  263,  263,  266,  266,
      267,  274,  274,  435,  267,  435,  229,  246,  597,  229,
      280,  236,  278,  278,  280,  287,  287,  236,  290,  290,
      306,  260,  298,  298,  306,  314,  314,  320,  266,  323,
      323,  320,  328,  328,  278,  278,  330,  330,  331,  331,
      287,  394,  332,  274,  330,  290,  332,  341,  341,  351,
      351,  394,  287,  353,  353,  314,  323,  375,  298,  361,
      361,  375,  328,  362,  362,  378,  378,  380,  380,  341,
      341,  389,  384,  391,  391,  351,  384,  389,  353,  399,
      399,  396,  396,  398,  398,  593,  361,  378,  362,  396,

      353,  398,  415,  415,  399,  399,  592,  380,  423,  423,
      391,  425,  425,  591,  427,  427,  431,  431,  438,  443,
      443,  534,  438,  447,  447,  534,  396,  590,  415,  452,
      452,  588,  457,  457,  587,  423,  463,  463,  425,  427,
      457,  443,  464,  464,  463,  467,  467,  468,  468,  472,
      472,  497,  431,  447,  452,  497,  468,  464,  464,  497,
      467,  467,  468,  468,  486,  486,  487,  487,  492,  492,
      586,  472,  486,  503,  503,  507,  507,  513,  513,  518,
      518,  519,  519,  524,  524,  525,  525,  518,  531,  531,
      555,  555,  583,  487,  525,  582,  519,  519,  524,  524,

      525,  525,  513,  503,  492,  507,  528,  528,  532,  532,
      531,  541,  541,  542,  542,  528,  532,  562,  562,  541,
      555,  528,  528,  566,  566,  562,  567,  567,  542,  542,
      581,  570,  570,  576,  576,  567,  575,  575,  566,  566,
      570,  567,  567,  578,  575,  577,  570,  570,  576,  576,
      584,  584,  585,  585,  599,  599,  600,  600,  607,  607,
      573,  585,  599,  572,  565,  584,  584,  585,  585,  603,
      603,  600,  600,  607,  607,  611,  611,  564,  603,  608,
      608,  614,  614,  560,  603,  603,  624,  624,  608,  557,
      614,  629,  629,  556,  608,  608,  614,  614,  625,  625,

      611,  624,  624,  626,  626,  641,  641,  625,  636,  636,
      643,  643,  626,  625,  625,  554,  629,  636,  626,  626,
      553,  552,  551,  636,  636,  549,  547,  641,  546,  545,
      544,  543,  643,  540,  539,  538,  536,  535,  530,  527,
      526,  522,  520,  517,  516,  515,  514,  512,  510,  509,
      508,  506,  502,  501,  498,  496,  494,  493,  491,  489,
      488,  485,  484,  483,  478,  477,  476,  474,  473,  471,
      466,  465,  462,  460,  459,  458,  456,  455,  453,  451,
      450,  449,  448,  444,  442,  441,  440,  439,  437,  436,
      434,  433,  429,  428,  426,  422,  421,  420,  419,  416,

      414,  413,  412,  410,  409,  407,  406,  405,  404,  403,
      402,  401,  400,  397,  395,  393,  392,  390,  388,  387,
      386,  385,  383,  382,  381,  379,  377,  376,  374,  373,
      371,  370,  368,  367,  366,  365,  364,  363,  360,  359,
      358,  357,  356,  355,  354,  352,  350,  347,  346,  344,
      343,  342,  339,  337,  335,  334,  333,  329,  327,  326,
      325,  324,  322,  321,  319,  318,  317,  316,  315,  313,
      311,  310,  309,  308,  307,  305,  304,  303,  302,  301,
      300,  299,  297,  296,  295,  294,  293,  292,  291,  289,
      288,  286,  285,  284,  283,  282,  281,  279,  277,  276,

      275,  273,  272,  271,  270,  269,  268,  265,  264,  262,
      261,  259,  258,  255,  254,  248,  247,  245,  244,  243,
      242,  241,  240,  239,  238,  237,  235,  234,  233,  232,
      231,  228,  227,  226,  225,  223,  221,  220,  219,  218,
      217,  214,  212,  211,  210,  209,  208,  207,  206,  205,
      204,  202,  201,  200,  199,  178,  177,  176,  173,  172,
      171,  170,  169,  168,  166,  165,  164,  163,  162,  161,
      160,  159,  156,  154,  153,  152,  151,  150,  149,  148,
      147,  146,  145,  144,  143,  141,  140,  139,  137,  136,
      135,  134,  133,  130,  129,  128,  127,  126,  121,  119,

      114,  113,  112,  111,  110,  109,  108,  107,  105,  104,
      102,  101,   99,   98,   97,   96,   95,   94,   93,   92,
       91,   90,   89,   87,   86,   85,   84,   83,   81,   79,
       77,   75,   74,   73,   72,   62,   58,   57,   56,   55,
       54,   53,   52,   51,   50,   49,   48,   47,   46,   45,
       43,   32,   24,   23,   21,   20,   17,   16,   15,   14,
       12,   11,    9,    8,    7,    4,    3,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,

      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645,  645,  645,  645,
      645,  645,  645,  645,  645,  645,  645
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "lexer.l"
#line 5 "lexer.l"
/* the directives above are for Solaris lex, and will be ignored by
 * flex */

/*
 * NAME
 *   lexer.l -- source for the C-INTERCAL lexical analyzer.
 */
// SPDX-FileCopyrightText: (C) Eric S. Raymond <esr@thyrsus.com>
// SPDX-License-Identifier: GPL-2.0-or-later

#include "config.h"
#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <string.h>
#include "ick.h"
#include "parser.h"
#include "ick_lose.h"

/*#undef wchar_t*/
/*#define wchar_t unsigned char*/

#if !defined yywrap || defined FLEX_SCANNER &&                          \
    (YY_FLEX_MAJOR_VERSION > 2 ||                                       \
     YY_FLEX_MAJOR_VERSION == 2 &&                                      \
         (YY_FLEX_MINOR_VERSION > 6 ||                                  \
          YY_FLEX_MINOR_VERSION == 6 && YY_FLEX_SUBMINOR_VERSION >= 3))
static int yywrap(void)
{
    return 1;
}
#endif /* yywrap */

int 	iyylineno = 1;

#ifdef MAIN
YYSTYPE	yylval;
#endif /* MAIN */

char **textlines = NULL;
int textlinecount = 0;
int politesse = 0;
int stbeginline = 0;

/* AIS: Sort out a grammar near-ambiguity */
unsigned long sparkearsstack[SENESTMAX] = {0};
int sparkearslev = 0;

/* AIS: Some symbols are ambiguous between C-INTERCAL and CLC-INTERCAL:
   Symbol    C-INTERCAL CLC-INTERCAL
   NOSPOT    _          @
   WHIRL     @          ?
   XOR       ?          yen, or bookworm (bookworm's also C-INTERCAL legal)
   By default, the C-INTERCAL meanings are used; the extern variable clclex
   causes CLC-INTERCAL interpretations to be put on the ambiguous symbols.
   Otherwise, mixing syntaxes freely is allowed. */
extern bool clclex;

#ifdef FLEX_SCANNER
static char linebuf[YY_BUF_SIZE];
#else /* FLEX_SCANNER */
static char linebuf[YYLMAX];
#endif /* FLEX_SCANNER */

static char *lineptr = linebuf;

bool re_send_token = false;

int lexer(void);
static int myatoi(const char *text);
void yyerror(const char *errtype);

#define SETLINENO					\
    {if (stbeginline == 0)	stbeginline = iyylineno;\
     else if (stbeginline < 0)	stbeginline = 0;}

/* AIS: Keep track of the spark/ears situation */
#define STACKSPARKEARS(a) \
    if (sparkearslev+1>=SENESTMAX*32) ick_lose(IE281, iyylineno, (char*) NULL); \
    sparkearslev++; sparkearsstack[sparkearslev/32]<<=1; \
    sparkearsstack[sparkearslev/32]+=a
#define CLEARSPARKEARSTACK {int i=SENESTMAX; \
                           while(i--) sparkearsstack[i] = 0;} \
                           sparkearslev = 0

/*
 * The spectacular ugliness of INTERCAL syntax requires that the lexical
 * analyzer have two levels. One, embedded in the getc() function, handles
 * logical-line continuation and the ! abbrev, and stashes each logical
 * line away in a buffer accessible to the code generator (this is necessary
 * for the * construct to be interpreted correctly). The upper level is
 * generated by lex(1) and does normal tokenizing.
 */

#undef getc
int getc(FILE *fp)
{
    extern FILE* yyin;

    static bool bangflag = false;
    static bool backflag = false;

    static bool eolflag = false;

    if ((size_t)(lineptr - linebuf) > sizeof linebuf)
      ick_lose(IE666, iyylineno, (char *)NULL);

    if (bangflag)
    {
	bangflag = false;
	/*	*lineptr++ = '!'; */
	return('.');
    }
    else if (backflag)	/* converting ctrl-H (backspace) to two chars "^H" */
    {
	backflag = false;
	/*	*lineptr++ = '\b'; */
	return('H');
    }
    else
    {
      int c;
      char c_char;
      size_t dummy;
      /*fprintf(stderr,"about to fgetc(\045p)",(void*)fp);*/

      c_char=0; /* AIS */
      dummy = fread(&c_char,1,1,fp);
      /* AIS: ignore the first \r in a row to deal with DOS newlines. The
	 second in a row is definitely an error, though, and will be caught
	 later on. */
      if(c_char=='\r') dummy = fread(&c_char,1,1,fp);
      c = c_char;

      if(feof(fp)) c=EOF;
      if(!eolflag && c == EOF) c = '\n';

      /*fprintf(stderr,"getc input a character: %c\n",c);*/

      if (feof(yyin))
      {
	*lineptr = '\0';
	if(eolflag) return(EOF);
	if(c=='\0' || c==EOF) c='\n';
      }

      eolflag = false;

      if (c == '!')
      {
	*lineptr++ = '!';
	bangflag = true;
	return(c = '\'');
      }
      else if (c == '\b')	/* convert ctrl-H (backspace) to
				   two chars "^" and "H" so lex can take it */
      {
	*lineptr++ = '\b';
	backflag = true;
	return(c = '^');
      }
      else if (c == '\n')
      {
	*lineptr = '\0';
	lineptr = linebuf;
	if (iyylineno >= textlinecount)
	{
	  textlinecount += ALLOC_CHUNK;
	  if (textlines)
	    textlines = realloc(textlines,
				textlinecount * sizeof(char*));
	  else
	    textlines = malloc(textlinecount * sizeof(char*));
	  if (!textlines)
	    ick_lose(IE666, iyylineno, (char *)NULL);
	}
	textlines[iyylineno] = malloc(1 + strlen(linebuf));
	if (!textlines[iyylineno])
	  ick_lose(IE666, iyylineno, (char *)NULL);
	strcpy(textlines[iyylineno], linebuf);
	iyylineno++;
	eolflag=true;
	return('\n');
      }
      else
      {
	return(*lineptr++ = c);
      }
    }
}

/* replace YY_INPUT so that it uses our getc function. */
#undef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	{ \
	  int c = getc(yyin); \
	  if (c == EOF) { \
	    if (ferror(yyin)) \
	      YY_FATAL_ERROR("input in flex scanner failed"); \
	    result = YY_NULL; \
	  } else { \
	    buf[0] = c; \
	    result = 1; \
	  } \
	}

#line 1093 "src/lexer.c"
#line 1094 "src/lexer.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 217 "lexer.l"


#line 1314 "src/lexer.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 646 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 968 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 219 "lexer.l"
{yylval.numval = myatoi(yytext); return(NUMBER);}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 220 "lexer.l"
{return(NOSPOT);}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 221 "lexer.l"
{return(ick_ONESPOT);}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 222 "lexer.l"
{return(ick_TWOSPOT);}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 223 "lexer.l"
{return(ick_TAIL);}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 224 "lexer.l"
{return(ick_HYBRID);}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 225 "lexer.l"
{return(MESH);}
	YY_BREAK
case 8:
#line 228 "lexer.l"
case 9:
#line 229 "lexer.l"
case 10:
YY_RULE_SETUP
#line 229 "lexer.l"
{return(MINGLE); /* AIS: CLC-INTERCAL ick_mingle symbols.
				    The \xBD is ISO-8859-1 for cent. */}
	YY_BREAK
case 11:
#line 232 "lexer.l"
case 12:
#line 233 "lexer.l"
case 13:
#line 234 "lexer.l"
case 14:
#line 235 "lexer.l"
case 15:
#line 236 "lexer.l"
case 16:
#line 237 "lexer.l"
case 17:
#line 238 "lexer.l"
case 18:
#line 239 "lexer.l"
case 19:
#line 240 "lexer.l"
case 20:
#line 241 "lexer.l"
case 21:
#line 242 "lexer.l"
case 22:
#line 243 "lexer.l"
case 23:
#line 244 "lexer.l"
case 24:
#line 245 "lexer.l"
case 25:
#line 246 "lexer.l"
case 26:
#line 247 "lexer.l"
case 27:
#line 248 "lexer.l"
case 28:
#line 249 "lexer.l"
case 29:
#line 250 "lexer.l"
case 30:
#line 251 "lexer.l"
case 31:
#line 252 "lexer.l"
case 32:
#line 253 "lexer.l"
case 33:
YY_RULE_SETUP
#line 253 "lexer.l"
{return(MINGLE);}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 255 "lexer.l"
{return(SELECT);}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 257 "lexer.l"
{return(SLAT); /* AIS: Operand overloading */}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 258 "lexer.l"
{return(BACKSLAT); /* ditto */}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 260 "lexer.l"
{yylval.numval = AND; return(UNARY);}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 261 "lexer.l"
{yylval.numval = OR; return(UNARY);}
	YY_BREAK
case 39:
#line 263 "lexer.l"
case 40:
#line 264 "lexer.l"
case 41:
#line 265 "lexer.l"
case 42:
YY_RULE_SETUP
#line 265 "lexer.l"
{yylval.numval = XOR; return(UNARY);
                 /* AIS: CLC-INTERCAL uses \xBE, ISO-8859-1 for yen;
                    for some reason, \xA5 is what was detected by the compiler
		    during my tests, so that's here too */}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 269 "lexer.l"
{if(clclex) yylval.numval = WHIRL;
                 else yylval.numval = XOR; return(UNARY);
                 /* AIS: ? is a unary operator in both C-INTERCAL and
		    CLC-INTERCAL, but with different meanings. */}
	YY_BREAK
case 44:
#line 274 "lexer.l"
case 45:
YY_RULE_SETUP
#line 274 "lexer.l"
{yylval.numval = FIN; return(UNARY); /* AIS: | is CLC */}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 275 "lexer.l"
{if(clclex) return(NOSPOT); /* AIS: a C/CLC ambiguity */
                 else {yylval.numval = WHIRL; return(UNARY);}}
	YY_BREAK
case 47:
/* rule 47 can match eol */
YY_RULE_SETUP
#line 277 "lexer.l"
{yylval.numval = WHIRL + myatoi(yytext) - 1; return(UNARY);}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 279 "lexer.l"
{char temp = sparkearsstack[sparkearslev/32]&1;
                 STACKSPARKEARS(0); /* AIS: I added all mentions of
				       STACKSPARKEARS, OPEN\(SPARK\|EARS\),
				       CLOSE\(SPARK\|EARS\),
				       and CLEARSPARKEARSTACK */
                 return(temp?OPENSPARK:CLOSESPARK);}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 285 "lexer.l"
{char temp = sparkearsstack[sparkearslev/32]&1;
                 STACKSPARKEARS(1);
                 return(temp?CLOSEEARS:OPENEARS);}
	YY_BREAK
case 50:
/* rule 50 can match eol */
YY_RULE_SETUP
#line 289 "lexer.l"
{SETLINENO; yylval.numval = myatoi(yytext); return(LABEL);}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 291 "lexer.l"
{SETLINENO; CLEARSPARKEARSTACK; return(DO);}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 292 "lexer.l"
{SETLINENO; CLEARSPARKEARSTACK; return(DO);}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 293 "lexer.l"
{SETLINENO; CLEARSPARKEARSTACK; politesse++; return(DO);}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 294 "lexer.l"
{SETLINENO; CLEARSPARKEARSTACK; politesse++; return(DO);}
	YY_BREAK
case 55:
/* rule 55 can match eol */
YY_RULE_SETUP
#line 295 "lexer.l"
{SETLINENO; CLEARSPARKEARSTACK; politesse++; return(DO);}
	YY_BREAK
case 56:
/* rule 56 can match eol */
YY_RULE_SETUP
#line 296 "lexer.l"
{SETLINENO; CLEARSPARKEARSTACK; politesse++; return(DO);}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 297 "lexer.l"
{SETLINENO; CLEARSPARKEARSTACK; return(MAYBE);}
	YY_BREAK
case 58:
/* rule 58 can match eol */
YY_RULE_SETUP
#line 298 "lexer.l"
{SETLINENO; CLEARSPARKEARSTACK; return(MAYBE);}
	YY_BREAK
case 59:
/* rule 59 can match eol */
YY_RULE_SETUP
#line 299 "lexer.l"
{SETLINENO; CLEARSPARKEARSTACK; politesse++; return(MAYBE);}
	YY_BREAK
case 60:
/* rule 60 can match eol */
YY_RULE_SETUP
#line 300 "lexer.l"
{SETLINENO; CLEARSPARKEARSTACK; politesse++; return(MAYBE);
                     /* AIS: I added all the MAYBE cases. It seems that MAYBE
                             has no simple Latin synonym. */}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 304 "lexer.l"
{return(NOT);}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 305 "lexer.l"
{return(NOT);}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 306 "lexer.l"
{return(NOT);}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 307 "lexer.l"
{return(NOT); /* AIS: CLC-INTERCAL again, this time it's
				 ISO-8859-1 for the logical NOT symbol... */}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 309 "lexer.l"
{return(NOT); /* ... but my computer translates it to \xAC */}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 311 "lexer.l"
{return(ONCE);}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 312 "lexer.l"
{return(ONCE);}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 313 "lexer.l"
{return(AGAIN);}
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 314 "lexer.l"
{return(AGAIN);}
	YY_BREAK
case 70:
/* rule 70 can match eol */
YY_RULE_SETUP
#line 316 "lexer.l"
{yylval.numval = myatoi(yytext);
                 if (yylval.numval && yylval.numval < 100)
		   return(OHOHSEVEN);
		 else
		   ick_lose(IE017, iyylineno, (char *)NULL);}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 321 "lexer.l"
{return(SUB);}
	YY_BREAK
case 72:
/* rule 72 can match eol */
#line 323 "lexer.l"
case 73:
/* rule 73 can match eol */
YY_RULE_SETUP
#line 323 "lexer.l"
{return(BY);}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 325 "lexer.l"
{return(GETS);}
	YY_BREAK
case 75:
#line 327 "lexer.l"
case 76:
YY_RULE_SETUP
#line 327 "lexer.l"
{yylval.numval = GETS; return(GERUND);}
	YY_BREAK
case 77:
#line 330 "lexer.l"
case 78:
YY_RULE_SETUP
#line 330 "lexer.l"
{return(FORGET);}
	YY_BREAK
case 79:
#line 332 "lexer.l"
case 80:
YY_RULE_SETUP
#line 332 "lexer.l"
{yylval.numval = FORGET; return(GERUND);}
	YY_BREAK
case 81:
#line 334 "lexer.l"
case 82:
YY_RULE_SETUP
#line 334 "lexer.l"
{return(RESUME);}
	YY_BREAK
case 83:
#line 336 "lexer.l"
case 84:
YY_RULE_SETUP
#line 336 "lexer.l"
{yylval.numval = RESUME; return(GERUND);}
	YY_BREAK
case 85:
#line 338 "lexer.l"
case 86:
YY_RULE_SETUP
#line 338 "lexer.l"
{return(STASH);}
	YY_BREAK
case 87:
#line 340 "lexer.l"
case 88:
YY_RULE_SETUP
#line 340 "lexer.l"
{yylval.numval = STASH; return(GERUND);}
	YY_BREAK
case 89:
#line 342 "lexer.l"
case 90:
YY_RULE_SETUP
#line 342 "lexer.l"
{return(RETRIEVE);}
	YY_BREAK
case 91:
#line 344 "lexer.l"
case 92:
YY_RULE_SETUP
#line 344 "lexer.l"
{yylval.numval = RETRIEVE; return(GERUND);}
	YY_BREAK
case 93:
#line 346 "lexer.l"
case 94:
YY_RULE_SETUP
#line 346 "lexer.l"
{return(IGNORE);}
	YY_BREAK
case 95:
#line 348 "lexer.l"
case 96:
YY_RULE_SETUP
#line 348 "lexer.l"
{yylval.numval = IGNORE; return(GERUND);}
	YY_BREAK
case 97:
#line 350 "lexer.l"
case 98:
YY_RULE_SETUP
#line 350 "lexer.l"
{return(REMEMBER);}
	YY_BREAK
case 99:
#line 352 "lexer.l"
case 100:
YY_RULE_SETUP
#line 352 "lexer.l"
{yylval.numval = REMEMBER; return(GERUND);}
	YY_BREAK
case 101:
#line 354 "lexer.l"
case 102:
YY_RULE_SETUP
#line 354 "lexer.l"
{return(ABSTAIN);}
	YY_BREAK
case 103:
#line 356 "lexer.l"
case 104:
YY_RULE_SETUP
#line 356 "lexer.l"
{yylval.numval = ABSTAIN; return(GERUND);}
	YY_BREAK
case 105:
#line 358 "lexer.l"
case 106:
YY_RULE_SETUP
#line 358 "lexer.l"
{return(REINSTATE);}
	YY_BREAK
case 107:
#line 360 "lexer.l"
case 108:
YY_RULE_SETUP
#line 360 "lexer.l"
{yylval.numval = REINSTATE; return(GERUND);}
	YY_BREAK
case 109:
/* rule 109 can match eol */
#line 362 "lexer.l"
case 110:
/* rule 110 can match eol */
YY_RULE_SETUP
#line 362 "lexer.l"
{return(READ_OUT);}
	YY_BREAK
case 111:
#line 364 "lexer.l"
case 112:
/* rule 112 can match eol */
YY_RULE_SETUP
#line 364 "lexer.l"
{yylval.numval = READ_OUT; return(GERUND);}
	YY_BREAK
case 113:
/* rule 113 can match eol */
#line 366 "lexer.l"
case 114:
/* rule 114 can match eol */
YY_RULE_SETUP
#line 366 "lexer.l"
{return(WRITE_IN);}
	YY_BREAK
case 115:
#line 368 "lexer.l"
case 116:
/* rule 116 can match eol */
YY_RULE_SETUP
#line 368 "lexer.l"
{yylval.numval = WRITE_IN; return(GERUND);}
	YY_BREAK
case 117:
#line 370 "lexer.l"
case 118:
#line 371 "lexer.l"
case 119:
#line 372 "lexer.l"
case 120:
YY_RULE_SETUP
#line 372 "lexer.l"
{yylval.numval = UNKNOWN; return(GERUND);
                 /* AIS: An idea stolen from CLC-INTERCAL.
		    The Latin means literally 'remind' or 'mention'. */}
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 375 "lexer.l"
{/* By AIS. I can't find a Latin translation for this. */
                 return(PIN);}
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 377 "lexer.l"
{/* By AIS */ yylval.numval = PIN; return(GERUND);}
	YY_BREAK
case 123:
/* rule 123 can match eol */
#line 379 "lexer.l"
case 124:
/* rule 124 can match eol */
YY_RULE_SETUP
#line 379 "lexer.l"
{/* AIS */ yylval.numval = myatoi(yytext);
			  return(NEXTFROMLABEL);}
	YY_BREAK
case 125:
/* rule 125 can match eol */
#line 382 "lexer.l"
case 126:
/* rule 126 can match eol */
YY_RULE_SETUP
#line 382 "lexer.l"
{/* AIS: 'next' is not a verb, so the Latin is invented */
                 return(NEXTFROMEXPR);}
	YY_BREAK
case 127:
#line 385 "lexer.l"
case 128:
/* rule 128 can match eol */
YY_RULE_SETUP
#line 385 "lexer.l"
{/* AIS */ yylval.numval = NEXTFROMLABEL; return(GERUND);}
	YY_BREAK
case 129:
/* rule 129 can match eol */
#line 387 "lexer.l"
case 130:
/* rule 130 can match eol */
YY_RULE_SETUP
#line 387 "lexer.l"
{/* AIS */ yylval.numval = myatoi(yytext);
			  return(COME_FROM);}
	YY_BREAK
case 131:
/* rule 131 can match eol */
#line 390 "lexer.l"
case 132:
/* rule 132 can match eol */
YY_RULE_SETUP
#line 390 "lexer.l"
{/* AIS */ return(COMPUCOME);}
	YY_BREAK
case 133:
#line 392 "lexer.l"
case 134:
/* rule 134 can match eol */
YY_RULE_SETUP
#line 392 "lexer.l"
{yylval.numval = COME_FROM; return(GERUND);}
	YY_BREAK
case 135:
#line 394 "lexer.l"
case 136:
YY_RULE_SETUP
#line 394 "lexer.l"
{stbeginline = 0; return(NEXT);}
	YY_BREAK
case 137:
#line 396 "lexer.l"
case 138:
YY_RULE_SETUP
#line 396 "lexer.l"
{yylval.numval = NEXT; return(GERUND);}
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 397 "lexer.l"
{return(FROM); /* AIS: Latin is 'A', which confuses the rest
                                  of the parser */}
	YY_BREAK
case 140:
#line 400 "lexer.l"
case 141:
#line 401 "lexer.l"
case 142:
/* rule 142 can match eol */
YY_RULE_SETUP
#line 401 "lexer.l"
{return(GIVE_UP);}
	YY_BREAK
case 143:
/* rule 143 can match eol */
#line 403 "lexer.l"
case 144:
/* rule 144 can match eol */
YY_RULE_SETUP
#line 403 "lexer.l"
{return(TRY_AGAIN);}
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 404 "lexer.l"
{return(WHILE); /* AIS. Latin for this is needed. */}
	YY_BREAK
case 146:
#line 406 "lexer.l"
case 147:
YY_RULE_SETUP
#line 406 "lexer.l"
{yylval.numval = WHILE; return(GERUND);}
	YY_BREAK
case 148:
/* rule 148 can match eol */
YY_RULE_SETUP
#line 407 "lexer.l"
{yylval.numval = TRY_AGAIN; return(GERUND);}
	YY_BREAK
case 149:
/* rule 149 can match eol */
#line 409 "lexer.l"
case 150:
/* rule 150 can match eol */
YY_RULE_SETUP
#line 409 "lexer.l"
{return(GO_BACK);}
	YY_BREAK
case 151:
/* rule 151 can match eol */
#line 411 "lexer.l"
case 152:
/* rule 152 can match eol */
YY_RULE_SETUP
#line 411 "lexer.l"
{yylval.numval = GO_BACK; return(GERUND);}
	YY_BREAK
case 153:
/* rule 153 can match eol */
#line 413 "lexer.l"
case 154:
/* rule 154 can match eol */
YY_RULE_SETUP
#line 413 "lexer.l"
{return(GO_AHEAD);}
	YY_BREAK
case 155:
/* rule 155 can match eol */
YY_RULE_SETUP
#line 414 "lexer.l"
{yylval.numval = GO_AHEAD; return(GERUND);
		 /* AIS: I'm having a few deponent troubles with the Latin, so
		    there are no Latin gerunds around here. Besides, the Latin
		    'gerunds' look somewhat like gerundives to me, but that's
		    purely based on memory so I may be wrong. */}
	YY_BREAK
case 156:
/* rule 156 can match eol */
#line 420 "lexer.l"
case 157:
/* rule 157 can match eol */
YY_RULE_SETUP
#line 420 "lexer.l"
{yylval.numval = myatoi(yytext); return(CREATE);}
	YY_BREAK
case 158:
#line 422 "lexer.l"
case 159:
YY_RULE_SETUP
#line 422 "lexer.l"
{return(COMPUCREATE);}
	YY_BREAK
case 160:
#line 424 "lexer.l"
case 161:
#line 425 "lexer.l"
case 162:
YY_RULE_SETUP
#line 425 "lexer.l"
{yylval.numval = CREATE; return(GERUND);}
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 427 "lexer.l"
{return(INTERSECTION);}
	YY_BREAK
case 164:
/* rule 164 can match eol */
YY_RULE_SETUP
#line 429 "lexer.l"
;
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 430 "lexer.l"
{/* AIS */ yylval.numval = *yytext; return(UNKNOWNID);}
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 431 "lexer.l"
{/* AIS */ yylval.numval = yytext[0]*256 + yytext[3];
		 if(yytext[0] > yytext[3])
		   yylval.numval = yytext[0] + yytext[3]*256;
                 return(BADCHAR);}
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 435 "lexer.l"
{yylval.numval = yytext[0]; /* AIS: The line below for debug */
 if(yydebug) fprintf(stdout, "yylex: bad char %#x\n",(unsigned char)yytext[0]);
                 return(BADCHAR);}
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 440 "lexer.l"
ECHO;
	YY_BREAK
#line 2074 "src/lexer.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 646 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 646 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 645);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp )
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 440 "lexer.l"


int lexer(void)
{
    static int tok = BADCHAR;

    if (re_send_token)
	re_send_token = false;
    else 
    {
	tok = yylex();
#ifdef YYDEBUG
	if (yydebug)
	    (void) fprintf(stdout, "yylex: returning token %d\n", tok); 
#endif /* YYDEBUG */
    }

#ifdef YYDEBUG
    if (yydebug)
	(void) fprintf(stdout, "lexer: returning token %d\n", tok); 
#endif /* YYDEBUG */
    return(tok);
}

static int myatoi(const char *text) /* AIS */
{
#define MAXTEXT 100
    static char buf[MAXTEXT];
    static char thinbuf[MAXTEXT];
    char* bp;
    char* tp;
    register int i;

    for(buf[i = 0] = '\0';*text && i < MAXTEXT;text++) {
	if(isdigit(*text)) {
	    buf[i++] = *text;
	}
    }
    buf[i] = '\0';
    bp=buf; tp=thinbuf;
    while(((*tp++=*bp++))); /* thinbuf code added by an AIS
			       in case we want to work with wchar_t;
			       the extra brackets tell GCC that this is
			       intended and not a mistaken assignment */
    return atoi(thinbuf);
}

void yyerror(const char *errtype)
{
#ifdef MAIN
    (void) printf("lextest: lexer error: %s.\n", errtype);
#else /* MAIN */
    (void) errtype;
#endif /* MAIN */
}

#ifdef MAIN
int ick_main(void)
{
	int	t;

	while ((t = yylex()) > 0)
	{
		(void) printf("%03d %09d\n", t, yylval.numval);
		yylval.numval = 0;
	}
	return 0;
}
#endif /* MAIN */

